@@ -7,6 +7,7 @@ from .CircularGauge import CircularGauge
 from .DataGrid import DataGrid
 from .DateBox import DateBox
 from .Drawer import Drawer
+from .FileUploader import FileUploader
 from .Form import Form
 from .FormButtonItem import FormButtonItem
 from .FormEmptyItem import FormEmptyItem
@@ -14,6 +15,7 @@ from .FormGroupItem import FormGroupItem
 from .FormSimpleItem import FormSimpleItem
 from .FormTab import FormTab
 from .FormTabbedItem import FormTabbedItem
+from .Gallery import Gallery
 from .LinearGauge import LinearGauge
 from .List import List
 from .LoadPanel import LoadPanel
@@ -45,6 +47,7 @@ __all__ = [
     "DataGrid",
     "DateBox",
     "Drawer",
+    "FileUploader",
     "Form",
     "FormButtonItem",
     "FormEmptyItem",
@@ -52,6 +55,7 @@ __all__ = [
     "FormSimpleItem",
     "FormTab",
     "FormTabbedItem",
+    "Gallery",
     "LinearGauge",
     "List",
     "LoadPanel",
